@@ -5,7 +5,7 @@ use strict;
 use v5.10;
 use Algorithm::LCSS;
 use CHI;
-use Cwd;
+use Cwd ();
 use Devel::StackTrace;
 use English qw(-no_match_vars);
 use File::Basename;
@@ -18,7 +18,7 @@ use Mojo::URL;
 use Mojo::Log;
 use Mojo::Base 'Mojo::UserAgent';
 use Mojo::File;
-use POSIX;
+use POSIX qw/O_WRONLY O_APPEND O_CREAT/;
 use Readonly;
 use String::Truncate;
 use Time::HiRes qw/time/;
@@ -26,7 +26,7 @@ use Time::HiRes qw/time/;
 Readonly my $HTTP_OK => 200;
 Readonly my $HTTP_FILE_NOT_FOUND => 404;
 
-our $VERSION = '1.15';
+our $VERSION = '1.17';
 
 # TODO: Timeout, fallback
 # TODO: Expected result content (json etc)
@@ -84,7 +84,6 @@ sub new {
         request_timeout
         server
         transactor
-
     /;
 
     my $ua = $class->SUPER::new(%mojo_agent_config);
@@ -164,11 +163,16 @@ sub start {
   my $key = $self->generate_key($url, @opts);
   my $start_time = time;
 
+  # Fork-safety
+  $self->_cleanup->server->restart if $self->{pid} && $self->{pid} ne $$;
+  $self->{pid} //= $$;
+
   # We wrap the incoming callback in our own callback to be able to cache the response
   my $wrapper_cb = $cb ? sub {
     my ($ua, $tx) = @_;
     $cb->($ua, $ua->_post_process_get($tx, $start_time, $key, @opts));
   } : ();
+
   # Is an absolute URL or an URL relative to the app eg. http://foo.com/ or /foo.txt
   if ($url !~ m{ \A file:// }gmx && (Mojo::URL->new($url)->is_abs || ($url =~ m{ \A / }gmx && !$self->always_return_file))) {
     if ($self->is_cacheable($key)) {
@@ -190,8 +194,7 @@ sub start {
         return $cached_tx;
       }
     }
-    # Fork-safety
-    $self->_cleanup->server->restart unless ($self->{pid} //= $$) eq $$;
+
     # Non-blocking
     if ($wrapper_cb) {
       warn "-- Non-blocking request (@{[_url($tx)]})\n" if Mojo::UserAgent::DEBUG;
